C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C****************************
C**     LDM_SET_NONL       **
C****************************
C
C
CD-Doc:
C NONLinearity     SUBROUTINE LDM_SET_NONL (VALUE, IERR, ERRSTR)
CD-end
      SUBROUTINE LDM_SET_NONL (VALUE, IERR, ERRSTR)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Set value of real parameter NONLINEARITY
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      REAL VALUE
      INTEGER IERR
      CHARACTER*(*) ERRSTR

C  VALUE     (R)   Value for the non-linearity parameter for film (any)
C  IERR      (W)   Error flag =0 OK
C  ERRSTR    (W)   Error description string if error found
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
      IERR = 0
      ERRSTR = ' '
      NONL = VALUE
      IS_NONL = 1
      CH_NONL = CH_MASK
      ND_NONL = -1000
      RETURN
      END
